@@ -1,22 +1,16 @@
-from fastapi.applications import FastAPI
-from fastapi.params import (
+from fastapi import (
     Body,
     Cookie,
     Depends,
+    FastAPI,
     File,
     Form,
     Header,
-    Param,
     Path,
     Query,
     Security,
 )
-from fastapi.security.http import HTTPBasic
-from fastapi.security.oauth2 import (
-    OAuth2,
-    OAuth2PasswordRequestData,
-    OAuth2PasswordRequestForm,
-)
+from fastapi.security import HTTPBasic, OAuth2, OAuth2PasswordRequestForm
 from pydantic import BaseModel
 from starlette.responses import HTMLResponse, JSONResponse, PlainTextResponse
 from starlette.status import HTTP_202_ACCEPTED
@@ -72,6 +66,91 @@ def get_path_param_required_id(item_id: str = Path(...)):
     return item_id
 
 
+@app.get("/path/param-minlength/{item_id}")
+def get_path_param_min_length(item_id: str = Path(..., min_length=3)):
+    return item_id
+
+
+@app.get("/path/param-maxlength/{item_id}")
+def get_path_param_max_length(item_id: str = Path(..., max_length=3)):
+    return item_id
+
+
+@app.get("/path/param-min_maxlength/{item_id}")
+def get_path_param_min_max_length(item_id: str = Path(..., max_length=3, min_length=2)):
+    return item_id
+
+
+@app.get("/path/param-gt/{item_id}")
+def get_path_param_gt(item_id: float = Path(..., gt=3)):
+    return item_id
+
+
+@app.get("/path/param-gt0/{item_id}")
+def get_path_param_gt0(item_id: float = Path(..., gt=0)):
+    return item_id
+
+
+@app.get("/path/param-ge/{item_id}")
+def get_path_param_ge(item_id: float = Path(..., ge=3)):
+    return item_id
+
+
+@app.get("/path/param-lt/{item_id}")
+def get_path_param_lt(item_id: float = Path(..., lt=3)):
+    return item_id
+
+
+@app.get("/path/param-lt0/{item_id}")
+def get_path_param_lt0(item_id: float = Path(..., lt=0)):
+    return item_id
+
+
+@app.get("/path/param-le/{item_id}")
+def get_path_param_le(item_id: float = Path(..., le=3)):
+    return item_id
+
+
+@app.get("/path/param-lt-gt/{item_id}")
+def get_path_param_lt_gt(item_id: float = Path(..., lt=3, gt=1)):
+    return item_id
+
+
+@app.get("/path/param-le-ge/{item_id}")
+def get_path_param_le_ge(item_id: float = Path(..., le=3, ge=1)):
+    return item_id
+
+
+@app.get("/path/param-lt-int/{item_id}")
+def get_path_param_lt_int(item_id: int = Path(..., lt=3)):
+    return item_id
+
+
+@app.get("/path/param-gt-int/{item_id}")
+def get_path_param_gt_int(item_id: int = Path(..., gt=3)):
+    return item_id
+
+
+@app.get("/path/param-le-int/{item_id}")
+def get_path_param_le_int(item_id: int = Path(..., le=3)):
+    return item_id
+
+
+@app.get("/path/param-ge-int/{item_id}")
+def get_path_param_ge_int(item_id: int = Path(..., ge=3)):
+    return item_id
+
+
+@app.get("/path/param-lt-gt-int/{item_id}")
+def get_path_param_lt_gt_int(item_id: int = Path(..., lt=3, gt=1)):
+    return item_id
+
+
+@app.get("/path/param-le-ge-int/{item_id}")
+def get_path_param_le_ge_int(item_id: int = Path(..., le=3, ge=1)):
+    return item_id
+
+
 @app.get("/query")
 def get_query(query):
     if query is None:
@@ -136,11 +215,6 @@ def get_header(head_name=Header(None, convert_underscores=False)):
     return head_name
 
 
-@app.get("/param")
-def get_param(par=Param(None)):
-    return par
-
-
 @app.get("/security")
 def get_security(sec=Security(HTTPBasic())):
     return sec
